@@ -31,6 +31,9 @@ def generate_url(image_url, **kwargs):
     image_url = _remove_schema(image_url)
 
     kwargs = dict(conf.THUMBOR_ARGUMENTS, **kwargs)
+    thumbor_server = kwargs.pop(
+        'thumbor_server', conf.THUMBOR_SERVER).rstrip('/')
+
     encrypted_url = crypto.generate(image_url=image_url, **kwargs).strip('/')
 
-    return '%s/%s' % (conf.THUMBOR_SERVER, encrypted_url)
+    return '%s/%s' % (thumbor_server, encrypted_url)
